@@ -46,7 +46,7 @@
 #include <QToolButton>
 #include <QToolTip>
 #include <QVBoxLayout>
-#include <QWindowsStyle>
+#include <QCommonStyle>
 
 using namespace Core;
 using namespace Internal;
@@ -243,7 +243,7 @@ FancyTabBar::FancyTabBar(QWidget *parent)
     : QWidget(parent)
 {
     setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);
-    setStyle(new QWindowsStyle);
+    setStyle(new QCommonStyle);
     setMinimumWidth(qMax(2 * m_rounding, 40));
     setAttribute(Qt::WA_Hover, true);
     setFocusPolicy(Qt::NoFocus);
